# python-core-client (Python + ConnectAPI ❤)
Client lib for communicating with the API backend


### My purpose
This library is responsible for secure communication with the ConnectAPI backend,
this mean refreshing the access token and validating it.

This library by it self can't communicate easily with the backend,
to communicate with a specific service you need to install the auto-generated library for that service,
you can get the information about this library and how to install it in the system dashboard under the service tab.

**This is a required library for every communication with the ConnectAPI backend**
